@@ -24,6 +24,7 @@
  *
  * 4. This notice may not be removed or altered.
  */
+#include "file.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -42,34 +43,40 @@
 #  endif
 # endif
 #endif
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>	/* for read() */
+#endif
 
 #include <netinet/in.h>		/* for byte swapping */
 
 #include "patchlevel.h"
-#include "file.h"
 
 #ifndef	lint
-FILE_RCSID("@(#)$Id: file.c,v 1.42 1998/09/12 13:17:52 christos Exp $")
+FILE_RCSID("@(#)$Id: file.c,v 1.46 1999/02/14 17:16:05 christos Exp $")
 #endif	/* lint */
 
 
 #ifdef S_IFLNK
-# define USAGE  "Usage: %s [-vbczL] [-f namefile] [-m magicfiles] file...\n"
+# define USAGE  "Usage: %s [-bcnvzL] [-f namefile] [-m magicfiles] file...\n"
 #else
-# define USAGE  "Usage: %s [-vbcz] [-f namefile] [-m magicfiles] file...\n"
+# define USAGE  "Usage: %s [-bcnvz] [-f namefile] [-m magicfiles] file...\n"
 #endif
 
 #ifndef MAGIC
 # define MAGIC "/etc/magic"
 #endif
 
+#ifndef MAXPATHLEN
+#define	MAXPATHLEN	512
+#endif
+
 int 			/* Global command-line options 		*/
 	debug = 0, 	/* debugging 				*/
 	lflag = 0,	/* follow Symlinks (BSD only) 		*/
 	bflag = 0,	/* brief output format	 		*/
-	zflag = 0;	/* follow (uncompress) compressed files */
-
+	zflag = 0,	/* follow (uncompress) compressed files */
+	sflag = 0,	/* read block special files		*/
+	nobuffer = 0;   /* Do not buffer stdout */
 int			/* Misc globals				*/
 	nmagic = 0;	/* number of valid magic[]s 		*/
 
@@ -94,8 +101,8 @@ int main __P((int, char *[]));
  */
 int
 main(argc, argv)
-int argc;
-char *argv[];
+	int argc;
+	char *argv[];
 {
 	int c;
 	int check = 0, didsomefiles = 0, errflg = 0, ret = 0, app = 0;
@@ -108,7 +115,7 @@ char *argv[];
 	if (!(magicfile = getenv("MAGIC")))
 		magicfile = MAGIC;
 
-	while ((c = getopt(argc, argv, "vbcdf:Lm:z")) != EOF)
+	while ((c = getopt(argc, argv, "bcdnf:m:svzL")) != EOF)
 		switch (c) {
 		case 'v':
 			(void) fprintf(stdout, "%s-%d.%d\n", progname,
@@ -120,6 +127,9 @@ char *argv[];
 		case 'c':
 			++check;
 			break;
+		case 'n':
+			++nobuffer;
+			break;
 		case 'd':
 			++debug;
 			break;
@@ -144,6 +154,9 @@ char *argv[];
 		case 'z':
 			zflag++;
 			break;
+		case 's':
+			sflag++;
+			break;
 		case '?':
 		default:
 			errflg++;
@@ -215,6 +228,8 @@ char *fn;
 	while (fgets(buf, MAXPATHLEN, f) != NULL) {
 		buf[strlen(buf)-1] = '\0';
 		process(buf, wid);
+		if(nobuffer)
+			(void) fflush(stdout);
 	}
 
 	(void) fclose(f);
